/************************************************************************/
/*                                                                      */
/* Copyright (C) 1997 Arve Kylling                                      */
/*                                                                      */
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 1, or (at your option)  */
/* any later version.                                                   */
/*                                                                      */
/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY of FITNESS FOR A PARTICULAR PURPOSE. See the         */
/* GNU General Public License for more details.                         */
/*                                                                      */
/* To obtain a copy of the GNU General Public License write to the      */
/* Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,   */
/* USA.                                                                 */
/*                                                                      */
/************************************************************************/

#include <stdio.h>							    
#include <stdlib.h>
#include "uvspec.h"
#include "../src_c/ascii.h"



/************************************/
/* prototypes of internal functions */
/************************************/

static int read_sza(char* sza_filename, atm_inp_struct *atm_inp, atm_out_struct *atm_out);



/**************************************************************/
/* Setup solar zenith and azimuth.                            */
/**************************************************************/

int setup_sza (input_struct input, output_struct *output)
{
  int status=0, iv=0;
  int linear=0;

  output->atm.sza_t  = (float *) calloc (output->wl.nlambda_t, sizeof(float));
  output->atm.phi0_t = (float *) calloc (output->wl.nlambda_t, sizeof(float));

  /* ??? is the if() statement correct ??? */
  if (input.atm.sza < -999.0) {
    status = read_sza(input.sza_filename, &input.atm, &output->atm);
    if ( status != 0.0 ) {
      fprintf (stderr, "Error reading sza file: %s\n",
	       input.sza_filename);
      return status;
    }
    
    /**** Interpolate sza to transmission grid ****/
    
    linear = 0;
    status = arb_wvn( output->atm.file_nlambda_sza, output->atm.file_lambda_sza,
		      output->atm.file_sza, 
		      output->wl.nlambda_t, output->wl.lambda_t, output->atm.sza_t, linear);

    status = arb_wvn( output->atm.file_nlambda_sza, output->atm.file_lambda_sza,
		      output->atm.file_phi0, 
		      output->wl.nlambda_t, output->wl.lambda_t, output->atm.phi0_t, linear);
  }
  else
    for (iv=0;iv<output->wl.nlambda_t;iv++) {
      output->atm.sza_t[iv]  = input.atm.sza;    
      output->atm.phi0_t[iv] = input.atm.phi0;    
    }

  return 0;
}



/**************************************************************/
/* Read solar zenith angles from file.                        */
/**************************************************************/

static int read_sza (char* sza_filename, atm_inp_struct *atm_inp, atm_out_struct *atm_out) 
{
  int i, rows=0, min_columns=0, max_columns=0;
  int status = 0;
  float **sza_data=NULL;
  
  status = ASCII_file2float (sza_filename, 
			      &rows, &max_columns, &min_columns, 
			      &sza_data);
  if (status!=0) {
    fprintf (stderr, " ... error %d opening file %s\n", status, sza_filename);
    return status;
  }
  if (max_columns!=min_columns) {
    fprintf (stderr, " !! ATTENTION !! Inconsistent number of columns\n");
    fprintf (stderr, "     min = %d, max =%d\n", min_columns, max_columns);
  }  
  if (min_columns<2) {
    fprintf (stderr, " ... ending, too few columns\n");
    return -1;
  }
  
  atm_out->file_nlambda_sza = rows;

  /*  printf("atm rows %d\n",rows);*/
  
  atm_out->file_sza = (float *) calloc (atm_out->file_nlambda_sza, sizeof(float));
  atm_out->file_phi0 = (float *) calloc (atm_out->file_nlambda_sza, sizeof(float));
  atm_out->file_lambda_sza = (float *) calloc (atm_out->file_nlambda_sza, sizeof(float));
  
  atm_out->file_lambda_sza = ASCII_column_float(sza_data, atm_out->file_nlambda_sza, 0 );
  atm_out->file_sza        = ASCII_column_float(sza_data, atm_out->file_nlambda_sza, 1 );
  if ( min_columns == 3) {
    atm_out->file_phi0       = ASCII_column_float(sza_data, atm_out->file_nlambda_sza, 2 );
  }
  else {
    for (i=0;i<atm_out->file_nlambda_sza;i++) {
      atm_out->file_phi0[i]  = 0.0;
    }
  }

  ASCII_free_float(sza_data,rows);

  return 0;
}





